@@ -49,6 +49,10 @@ NULL
 #'     that have a
 #'     [`rowRanges`][SummarizedExperiment::RangedSummarizedExperiment-class]
 #'     method
+#' * hasRowData: A function that identifies ExperimentList elements
+#'     that have a
+#'     [`rowData`][SummarizedExperiment::SummarizedExperiment-class]
+#'     method
 #' * getWithColData: A convenience function for extracting an assay
 #'     and associated colData
 #' * renamePrimary: A convenience function to rename the primary
@@ -339,8 +343,11 @@ setMethod("mergeReplicates", "ANY",
         return(object)
 })
 
-.matchAddColData <- function(reshaped, colData, colDataCols) {
-    extraColumns <- as.data.frame(colData[, colDataCols, drop = FALSE])
+.matchAddColData <- function(reshaped, colData, colDataCols, check.names) {
+    optional <- !check.names
+    extraColumns <- as.data.frame(
+        colData[, colDataCols, drop = FALSE], optional = optional
+    )
     rowNameValues <- rownames(extraColumns)
     rownames(extraColumns) <- NULL
     matchIdx <- match(reshaped[["primary"]], rowNameValues)
@@ -363,7 +370,7 @@ setMethod("mergeReplicates", "ANY",
 #' @rdname MultiAssayExperiment-helpers
 #'
 #' @details The `longForm` "ANY" class method, works with classes such as
-#' [`ExpressionSet`][Biobase::ExpressionSet] and
+#' \code{\link[Biobase:ExpressionSet-class]{ExpressionSet}} and
 #' [`SummarizedExperiment`][SummarizedExperiment::SummarizedExperiment-class] as
 #' well as `matrix` to provide a consistent long and skinny
 #' [`DataFrame`][S4Vectors::DataFrame-class].
@@ -405,8 +412,9 @@ setMethod(
         longDataFrame <- .mapOrderPrimary(longDataFrame, sampleMap(object))
 
         if (!is.null(colDataCols))
-            longDataFrame <-
-                .matchAddColData(longDataFrame, colData(object), colDataCols)
+            longDataFrame <- .matchAddColData(
+                longDataFrame, colData(object), colDataCols, TRUE
+            )
 
         as(longDataFrame, "DataFrame")
     }
@@ -520,13 +528,12 @@ setMethod("longForm", "ANY", function(object, colDataCols, i = 1L, ...) {
 #' See the `wideFormat` section for description of the `colDataCols` and
 #' `i` arguments.
 #'
-#' @param check.names (logical default TRUE) Column names of the output
-#' `DataFrame` will be checked for syntactic validity and made unique,
-#' if necessary
+#' @param check.names `logical(1)` Column names of the output `DataFrame` will
+#'   be run through `make.names` to ensure syntactic validity (default `TRUE`).
 #'
-#' @param collapse (character default "_") A single string delimiter for output
-#' column names. In `wideFormat`, experiments and rownames (and when
-#' replicate samples are present, colnames) are seperated by this delimiter
+#' @param collapse `character(1)` A single string delimiter (default "_") for
+#'   output column names. In `wideFormat`, experiments and `rownames` (and when
+#'   replicate samples are present, `colnames`) are separated by this delimiter
 #'
 #' @export wideFormat
 wideFormat <- function(object, colDataCols = NULL, check.names = TRUE,
@@ -584,7 +591,9 @@ wideFormat <- function(object, colDataCols = NULL, check.names = TRUE,
 
     wideData <- lapply(wideData, function(flox) {
         flox <- tidyr::pivot_wider(flox, names_from = key)
-        .matchAddColData(flox, colData(object), colDataCols)
+        .matchAddColData(
+            flox, colData(object), colDataCols, check.names
+        )
     })
     wideDF <- Reduce(function(x, y)
         merge(x, y, by = intersect(names(x), names(y)), all = TRUE), wideData)
@@ -599,6 +608,7 @@ wideFormat <- function(object, colDataCols = NULL, check.names = TRUE,
 
 # hasRowRanges section ----------------------------------------------------
 
+#' @importFrom MatrixGenerics rowRanges
 .tryRowRanges <- function(obj) {
     res <- try(rowRanges(obj), silent = TRUE)
     if (!is(res, "try-error"))
@@ -625,6 +635,8 @@ setGeneric("hasRowRanges", function(x) standardGeneric("hasRowRanges"))
 #' @details The `hasRowRanges` method identifies assays that support
 #' a [`rowRanges`][SummarizedExperiment::RangedSummarizedExperiment-class]
 #' method _and_ return a [`GRanges`][GenomicRanges::GRanges-class] object.
+#'
+#' @exportMethod hasRowRanges
 setMethod("hasRowRanges", "MultiAssayExperiment", function(x) {
     hasRowRanges(experiments(x))
 })
@@ -635,6 +647,44 @@ setMethod("hasRowRanges", "ExperimentList", function(x) {
     vapply(x, .tryRowRanges, logical(1L))
 })
 
+# hasRowData section ------------------------------------------------------
+
+#' @importFrom SummarizedExperiment rowData
+.tryRowData <- function(obj) {
+    res <- try(rowData(obj), silent = TRUE)
+    if (!is(res, "try-error"))
+        is(res, "DataFrame")
+    else
+        FALSE
+}
+
+#' @rdname MultiAssayExperiment-helpers
+#'
+#' @aliases hasRowData
+#'
+#' @details The `hasRowData` method identifies assays that support a
+#'   [`rowData`][SummarizedExperiment::SummarizedExperiment-class] method _and_
+#'   return a [`DataFrame`][S4Vectors::DataFrame-class] object.
+#'
+#' @export
+setGeneric("hasRowData", function(x) standardGeneric("hasRowData"))
+
+#' @describeIn MultiAssayExperiment-helpers The `hasRowData` method identifies
+#'   experiments that have a `rowData` method via direct testing
+#'
+#' @exportMethod hasRowData
+setMethod("hasRowData", "MultiAssayExperiment", function(x) {
+    hasRowData(experiments(x))
+})
+
+#' @describeIn MultiAssayExperiment-helpers The `hasRowData` method identifies
+#'   experiments that have a `rowData` method via direct testing
+#'
+#' @exportMethod hasRowData
+setMethod("hasRowData", "ExperimentList", function(x) {
+    vapply(x, .tryRowData, logical(1L))
+})
+
 #' @rdname MultiAssayExperiment-helpers
 #'
 #' @param mode String indicating how `MultiAssayExperiment`
